==> kameleoon_client_flutter-0.0.1.tar.gz: example/lib/Components/Button.dart <==
import 'package:flutter/material.dart';
import 'package:kameleoon_client_flutter_example/Pages/Login/login_page.dart';

import '../constants.dart';

class Button extends StatelessWidget {
  final String text;
  final Color bgColor;
  final BorderStyle borderStyle;
  final double borderWidth;
  final Color borderColor;
  final Color textColor;
  final Function onPress;

  const Button({
    Key key,
    this.text,
    this.bgColor,
    this.borderStyle,
    this.borderWidth,
    this.borderColor,
    this.textColor,
    this.onPress
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    Size screenSize = MediaQuery.of(context).size;
    return SizedBox(
        width: screenSize.width - 100,
        height: 50,
        child: TextButton(
          style: ButtonStyle(
            padding: MaterialStateProperty.all<EdgeInsets>(EdgeInsets.symmetric(vertical: 10, horizontal: 40)),
            backgroundColor: MaterialStateProperty.all<Color>(this.bgColor),
            shape: MaterialStateProperty.all<RoundedRectangleBorder>(
                RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(25),
                    side: BorderSide(
                        color: this.borderColor,
                        width: this.borderWidth,
                        style: this.borderStyle
                    )
                )
            ),
          ),
          child: Text(
            this.text,
            style: TextStyle(
                color: this.textColor
            ),
          ),
          onPressed: this.onPress,
        )
    );
  }
}

==> kameleoon_client_flutter-2.0.0.tar.gz: example/lib/Components/Button.dart <==
import 'package:flutter/material.dart';

class Button extends StatelessWidget {
  final String? text;
  final Color? bgColor;
  final BorderStyle? borderStyle;
  final double? borderWidth;
  final Color? borderColor;
  final Color? textColor;
  final VoidCallback? onPress;

  const Button({
    Key? key,
    this.text,
    this.bgColor,
    this.borderStyle,
    this.borderWidth,
    this.borderColor,
    this.textColor,
    this.onPress
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    Size screenSize = MediaQuery.of(context).size;
    return SizedBox(
        width: screenSize.width - 100,
        height: 50,
        child: TextButton(
          style: ButtonStyle(
            padding: MaterialStateProperty.all<EdgeInsets>(EdgeInsets.symmetric(vertical: 10, horizontal: 40)),
            backgroundColor: MaterialStateProperty.all<Color>(this.bgColor!),
            shape: MaterialStateProperty.all<RoundedRectangleBorder>(
                RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(25),
                    side: BorderSide(
                        color: this.borderColor!,
                        width: this.borderWidth!,
                        style: this.borderStyle!
                    )
                )
            ),
          ),
          child: Text(
            this.text!,
            style: TextStyle(
                color: this.textColor,
                fontSize: 12,
                fontWeight: FontWeight.w600
            ),
          ),
          onPressed: this.onPress,
        )
    );
  }
}
